#include <libint2.h>
#include <GenericContract.h>
#include <OSVRRP0InBra_aB_p__0__h__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0.h>

#ifdef __cplusplus
extern "C" {
#endif
void _aB_P__0__H__1___TwoPRep_S__0__H__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack) {

LIBINT2_REALTYPE*const  stack = parent_stack;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+753)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+756)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+759)*1+lsi)*1]), &(stack[((hsi*3+756)*1+lsi)*1]), &(stack[((hsi*3+753)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+765)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+768)*1+lsi)*1]), &(stack[((hsi*3+765)*1+lsi)*1]), &(stack[((hsi*3+756)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+774)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+777)*1+lsi)*1]), &(stack[((hsi*3+753)*1+lsi)*1]), &(stack[((hsi*3+774)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+783)*1+lsi)*1]), &(stack[((hsi*6+759)*1+lsi)*1]), &(stack[((hsi*6+777)*1+lsi)*1]), &(stack[((hsi*3+756)*1+lsi)*1]), &(stack[((hsi*3+753)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+793)*1+lsi)*1]), &(stack[((hsi*6+768)*1+lsi)*1]), &(stack[((hsi*6+759)*1+lsi)*1]), &(stack[((hsi*3+765)*1+lsi)*1]), &(stack[((hsi*3+756)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+803)*1+lsi)*1]), &(stack[((hsi*10+793)*1+lsi)*1]), &(stack[((hsi*10+783)*1+lsi)*1]), &(stack[((hsi*6+768)*1+lsi)*1]), &(stack[((hsi*6+759)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+756)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+818)*1+lsi)*1]), &(stack[((hsi*3+774)*1+lsi)*1]), &(stack[((hsi*3+756)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+824)*1+lsi)*1]), &(stack[((hsi*6+777)*1+lsi)*1]), &(stack[((hsi*6+818)*1+lsi)*1]), &(stack[((hsi*3+753)*1+lsi)*1]), &(stack[((hsi*3+774)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+834)*1+lsi)*1]), &(stack[((hsi*10+783)*1+lsi)*1]), &(stack[((hsi*10+824)*1+lsi)*1]), &(stack[((hsi*6+759)*1+lsi)*1]), &(stack[((hsi*6+777)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+849)*1+lsi)*1]), &(stack[((hsi*15+803)*1+lsi)*1]), &(stack[((hsi*15+834)*1+lsi)*1]), &(stack[((hsi*10+793)*1+lsi)*1]), &(stack[((hsi*10+783)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+753)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+759)*1+lsi)*1]), &(stack[((hsi*3+753)*1+lsi)*1]), &(stack[((hsi*3+765)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+870)*1+lsi)*1]), &(stack[((hsi*6+759)*1+lsi)*1]), &(stack[((hsi*6+768)*1+lsi)*1]), &(stack[((hsi*3+753)*1+lsi)*1]), &(stack[((hsi*3+765)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+880)*1+lsi)*1]), &(stack[((hsi*10+870)*1+lsi)*1]), &(stack[((hsi*10+793)*1+lsi)*1]), &(stack[((hsi*6+759)*1+lsi)*1]), &(stack[((hsi*6+768)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+895)*1+lsi)*1]), &(stack[((hsi*15+880)*1+lsi)*1]), &(stack[((hsi*15+803)*1+lsi)*1]), &(stack[((hsi*10+870)*1+lsi)*1]), &(stack[((hsi*10+793)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*63+916)*1+lsi)*1]), &(stack[((hsi*21+895)*1+lsi)*1]), &(stack[((hsi*21+849)*1+lsi)*1]), &(stack[((hsi*15+803)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*63+0)*1+lsi)*1]),&(stack[((hsi*63+916)*1+lsi)*1]),63);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+753)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+759)*1+lsi)*1]), &(stack[((hsi*3+756)*1+lsi)*1]), &(stack[((hsi*3+753)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+793)*1+lsi)*1]), &(stack[((hsi*6+818)*1+lsi)*1]), &(stack[((hsi*6+759)*1+lsi)*1]), &(stack[((hsi*3+774)*1+lsi)*1]), &(stack[((hsi*3+756)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+979)*1+lsi)*1]), &(stack[((hsi*10+824)*1+lsi)*1]), &(stack[((hsi*10+793)*1+lsi)*1]), &(stack[((hsi*6+777)*1+lsi)*1]), &(stack[((hsi*6+818)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+994)*1+lsi)*1]), &(stack[((hsi*15+834)*1+lsi)*1]), &(stack[((hsi*15+979)*1+lsi)*1]), &(stack[((hsi*10+783)*1+lsi)*1]), &(stack[((hsi*10+824)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+765)*1+lsi)*1]), &(stack[((hsi*21+849)*1+lsi)*1]), &(stack[((hsi*21+994)*1+lsi)*1]), &(stack[((hsi*15+803)*1+lsi)*1]), &(stack[((hsi*15+834)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1015)*1+lsi)*1]), &(stack[((hsi*21+895)*1+lsi)*1]), &(stack[((hsi*21+849)*1+lsi)*1]), &(stack[((hsi*15+880)*1+lsi)*1]), &(stack[((hsi*15+803)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*84+1043)*1+lsi)*1]), &(stack[((hsi*28+1015)*1+lsi)*1]), &(stack[((hsi*28+765)*1+lsi)*1]), &(stack[((hsi*21+849)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*84+63)*1+lsi)*1]),&(stack[((hsi*84+1043)*1+lsi)*1]),84);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+870)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+873)*1+lsi)*1]), &(stack[((hsi*3+753)*1+lsi)*1]), &(stack[((hsi*3+870)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+879)*1+lsi)*1]), &(stack[((hsi*6+759)*1+lsi)*1]), &(stack[((hsi*6+873)*1+lsi)*1]), &(stack[((hsi*3+756)*1+lsi)*1]), &(stack[((hsi*3+753)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+803)*1+lsi)*1]), &(stack[((hsi*10+793)*1+lsi)*1]), &(stack[((hsi*10+879)*1+lsi)*1]), &(stack[((hsi*6+818)*1+lsi)*1]), &(stack[((hsi*6+759)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1127)*1+lsi)*1]), &(stack[((hsi*15+979)*1+lsi)*1]), &(stack[((hsi*15+803)*1+lsi)*1]), &(stack[((hsi*10+824)*1+lsi)*1]), &(stack[((hsi*10+793)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1148)*1+lsi)*1]), &(stack[((hsi*21+994)*1+lsi)*1]), &(stack[((hsi*21+1127)*1+lsi)*1]), &(stack[((hsi*15+834)*1+lsi)*1]), &(stack[((hsi*15+979)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1176)*1+lsi)*1]), &(stack[((hsi*28+765)*1+lsi)*1]), &(stack[((hsi*28+1148)*1+lsi)*1]), &(stack[((hsi*21+849)*1+lsi)*1]), &(stack[((hsi*21+994)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1212)*1+lsi)*1]), &(stack[((hsi*28+1015)*1+lsi)*1]), &(stack[((hsi*28+765)*1+lsi)*1]), &(stack[((hsi*21+895)*1+lsi)*1]), &(stack[((hsi*21+849)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*108+1248)*1+lsi)*1]), &(stack[((hsi*36+1212)*1+lsi)*1]), &(stack[((hsi*36+1176)*1+lsi)*1]), &(stack[((hsi*28+765)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*108+147)*1+lsi)*1]),&(stack[((hsi*108+1248)*1+lsi)*1]),108);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+756)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+818)*1+lsi)*1]), &(stack[((hsi*3+870)*1+lsi)*1]), &(stack[((hsi*3+756)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+824)*1+lsi)*1]), &(stack[((hsi*6+873)*1+lsi)*1]), &(stack[((hsi*6+818)*1+lsi)*1]), &(stack[((hsi*3+753)*1+lsi)*1]), &(stack[((hsi*3+870)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+834)*1+lsi)*1]), &(stack[((hsi*10+879)*1+lsi)*1]), &(stack[((hsi*10+824)*1+lsi)*1]), &(stack[((hsi*6+759)*1+lsi)*1]), &(stack[((hsi*6+873)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+849)*1+lsi)*1]), &(stack[((hsi*15+803)*1+lsi)*1]), &(stack[((hsi*15+834)*1+lsi)*1]), &(stack[((hsi*10+793)*1+lsi)*1]), &(stack[((hsi*10+879)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1356)*1+lsi)*1]), &(stack[((hsi*21+1127)*1+lsi)*1]), &(stack[((hsi*21+849)*1+lsi)*1]), &(stack[((hsi*15+979)*1+lsi)*1]), &(stack[((hsi*15+803)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1384)*1+lsi)*1]), &(stack[((hsi*28+1148)*1+lsi)*1]), &(stack[((hsi*28+1356)*1+lsi)*1]), &(stack[((hsi*21+994)*1+lsi)*1]), &(stack[((hsi*21+1127)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1420)*1+lsi)*1]), &(stack[((hsi*36+1176)*1+lsi)*1]), &(stack[((hsi*36+1384)*1+lsi)*1]), &(stack[((hsi*28+765)*1+lsi)*1]), &(stack[((hsi*28+1148)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1465)*1+lsi)*1]), &(stack[((hsi*36+1212)*1+lsi)*1]), &(stack[((hsi*36+1176)*1+lsi)*1]), &(stack[((hsi*28+1015)*1+lsi)*1]), &(stack[((hsi*28+765)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*135+1510)*1+lsi)*1]), &(stack[((hsi*45+1465)*1+lsi)*1]), &(stack[((hsi*45+1420)*1+lsi)*1]), &(stack[((hsi*36+1176)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*135+255)*1+lsi)*1]),&(stack[((hsi*135+1510)*1+lsi)*1]),135);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+753)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+979)*1+lsi)*1]), &(stack[((hsi*3+756)*1+lsi)*1]), &(stack[((hsi*3+753)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+985)*1+lsi)*1]), &(stack[((hsi*6+818)*1+lsi)*1]), &(stack[((hsi*6+979)*1+lsi)*1]), &(stack[((hsi*3+870)*1+lsi)*1]), &(stack[((hsi*3+756)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+995)*1+lsi)*1]), &(stack[((hsi*10+824)*1+lsi)*1]), &(stack[((hsi*10+985)*1+lsi)*1]), &(stack[((hsi*6+873)*1+lsi)*1]), &(stack[((hsi*6+818)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+759)*1+lsi)*1]), &(stack[((hsi*15+834)*1+lsi)*1]), &(stack[((hsi*15+995)*1+lsi)*1]), &(stack[((hsi*10+879)*1+lsi)*1]), &(stack[((hsi*10+824)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+870)*1+lsi)*1]), &(stack[((hsi*21+849)*1+lsi)*1]), &(stack[((hsi*21+759)*1+lsi)*1]), &(stack[((hsi*15+803)*1+lsi)*1]), &(stack[((hsi*15+834)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+780)*1+lsi)*1]), &(stack[((hsi*28+1356)*1+lsi)*1]), &(stack[((hsi*28+870)*1+lsi)*1]), &(stack[((hsi*21+1127)*1+lsi)*1]), &(stack[((hsi*21+849)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1645)*1+lsi)*1]), &(stack[((hsi*36+1384)*1+lsi)*1]), &(stack[((hsi*36+780)*1+lsi)*1]), &(stack[((hsi*28+1148)*1+lsi)*1]), &(stack[((hsi*28+1356)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1690)*1+lsi)*1]), &(stack[((hsi*45+1420)*1+lsi)*1]), &(stack[((hsi*45+1645)*1+lsi)*1]), &(stack[((hsi*36+1176)*1+lsi)*1]), &(stack[((hsi*36+1384)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1745)*1+lsi)*1]), &(stack[((hsi*45+1465)*1+lsi)*1]), &(stack[((hsi*45+1420)*1+lsi)*1]), &(stack[((hsi*36+1212)*1+lsi)*1]), &(stack[((hsi*36+1176)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*165+1800)*1+lsi)*1]), &(stack[((hsi*55+1745)*1+lsi)*1]), &(stack[((hsi*55+1690)*1+lsi)*1]), &(stack[((hsi*45+1420)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*165+390)*1+lsi)*1]),&(stack[((hsi*165+1800)*1+lsi)*1]),165);
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1127)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1130)*1+lsi)*1]), &(stack[((hsi*3+753)*1+lsi)*1]), &(stack[((hsi*3+1127)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1136)*1+lsi)*1]), &(stack[((hsi*6+979)*1+lsi)*1]), &(stack[((hsi*6+1130)*1+lsi)*1]), &(stack[((hsi*3+756)*1+lsi)*1]), &(stack[((hsi*3+753)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1146)*1+lsi)*1]), &(stack[((hsi*10+985)*1+lsi)*1]), &(stack[((hsi*10+1136)*1+lsi)*1]), &(stack[((hsi*6+818)*1+lsi)*1]), &(stack[((hsi*6+979)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1161)*1+lsi)*1]), &(stack[((hsi*15+995)*1+lsi)*1]), &(stack[((hsi*15+1146)*1+lsi)*1]), &(stack[((hsi*10+824)*1+lsi)*1]), &(stack[((hsi*10+985)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1182)*1+lsi)*1]), &(stack[((hsi*21+759)*1+lsi)*1]), &(stack[((hsi*21+1161)*1+lsi)*1]), &(stack[((hsi*15+834)*1+lsi)*1]), &(stack[((hsi*15+995)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+979)*1+lsi)*1]), &(stack[((hsi*28+870)*1+lsi)*1]), &(stack[((hsi*28+1182)*1+lsi)*1]), &(stack[((hsi*21+849)*1+lsi)*1]), &(stack[((hsi*21+759)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1127)*1+lsi)*1]), &(stack[((hsi*36+780)*1+lsi)*1]), &(stack[((hsi*36+979)*1+lsi)*1]), &(stack[((hsi*28+1356)*1+lsi)*1]), &(stack[((hsi*28+870)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+816)*1+lsi)*1]), &(stack[((hsi*45+1645)*1+lsi)*1]), &(stack[((hsi*45+1127)*1+lsi)*1]), &(stack[((hsi*36+1384)*1+lsi)*1]), &(stack[((hsi*36+780)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+1127)*1+lsi)*1]), &(stack[((hsi*55+1690)*1+lsi)*1]), &(stack[((hsi*55+816)*1+lsi)*1]), &(stack[((hsi*45+1420)*1+lsi)*1]), &(stack[((hsi*45+1645)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*66+753)*1+lsi)*1]), &(stack[((hsi*55+1745)*1+lsi)*1]), &(stack[((hsi*55+1690)*1+lsi)*1]), &(stack[((hsi*45+1465)*1+lsi)*1]), &(stack[((hsi*45+1420)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__ps__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*198+1965)*1+lsi)*1]), &(stack[((hsi*66+753)*1+lsi)*1]), &(stack[((hsi*66+1127)*1+lsi)*1]), &(stack[((hsi*55+1690)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*198+555)*1+lsi)*1]),&(stack[((hsi*198+1965)*1+lsi)*1]),198);
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 753 */
}

#ifdef __cplusplus
};
#endif
